# Superdesk Core library
[![Build Status](https://travis-ci.org/superdesk/superdesk-core.png?branch=master)](https://travis-ci.org/superdesk/superdesk-core)
Utilities for building Superdesk applications.